| Safe Haskell | None |
|---|
HarmTrace.Models.ChordTokens
- data ChordToken = ChordToken {
- root :: ScaleDegree
- classType :: ClassType
- chords :: [ChordLabel]
- status :: ParseStatus
- chordNumReps :: Int
- dur :: Int
- data PieceToken = PieceToken Key [ChordToken]
- data ParseStatus
- toKeyRelTok :: Key -> [ChordLabel] -> [ChordToken]
Documentation
data ChordToken Source
Constructors
| ChordToken | |
Fields
| |
data PieceToken Source
Constructors
| PieceToken Key [ChordToken] |
data ParseStatus Source
Instances
toKeyRelTok :: Key -> [ChordLabel] -> [ChordToken]Source
Merges duplicate chords and transforms absolute chord labels into key relative tokens that can be parsed by the HarmTrace model